%% generate training sequence
%
% Author: Sebastian Musslick

examplesPerWord = 10;
recordingTime = 2;       % number seconds to record a word

% load settings
speechRecogSettings;

% generate pseudorandom sequence of words
sequence = repmat([1:length(settings.speechRecog.words)], 1, examplesPerWord);
sequence = sequence(randperm(length(sequence)));

%% record training data

% create audiorecorder object
recObj = audiorecorder(settings.speechRecog.fs, 8, 1, 0);

% counter for occurance of each word
counter = zeros(1, length(settings.speechRecog.words));

% before recording, make sure that data folder is empty
delete([settings.speechRecog.postDataFolder '/*.wav']);

% loop through each word in the sequence
for trial = 1:length(sequence)
    
    % present instructions & record audio
    clc;
    disp(strcat('Please say: ''', settings.speechRecog.words{sequence(trial)}, ''''));
    disp('Start speaking.')
    recordblocking(recObj, recordingTime);
    disp('End of Recording.');
    
    % add counter to recorded word
    counter(sequence(trial)) = counter(sequence(trial))  + 1;
    
    % encode category in file name (first number is word category, second number is occurance of that category)
    filename = [settings.speechRecog.postDataFolder '/' num2str(sequence(trial)) '_' num2str(counter(sequence(trial))) '.wav'];
    
    % write data to file
    data = getaudiodata(recObj);
    audiowrite(filename, data, recObj.SampleRate);
    
    % pause before presenting next word
    pause(0.5);
    clc;
    pause(0.5);
    
end



