%% validate data set
%
% Author: Sebastian Musslick

% load settings
speechRecogSettings;

% initialize evaluation variables
trueID = [];            % true class of the word
classifiedID = [];    % cassified class of the word
trueClass = [];            % true class of the word, in 1-of-N form
guessedClass = [];      %  guessed class of the word (same as classified, but random for non-assigned classes), in 1-of-N form
classifiedConfidence = [];  % classifier confidence
correct = [];            % accuracy
RTs = [];               % reaction time (onset of word
filenames = {};       % names of all processed files
counter = 1;

% move to folder with classification data
folder = settings.speechRecog.postDataFolder;
files = dir(folder);

% loop through all the audio files
disp('processing...');
for i = 1:length(files)
    
    % check if this is a wav file
    if(~isempty(strfind(files(i).name, '.wav')))
        
        % print file name
        disp(files(i).name);
        
        % get file name & path
        filenames{counter} = files(i).name;
        filepath = strcat(folder, '/', files(i).name);
        
        % identify word identiy (class) based on file name
        sepIdx = strfind(files(i).name,'_');
        dotIdx = strfind(files(i).name,'.');
        wordIdentity = str2double(files(i).name(1:(sepIdx-1)));
        
        % add correct class
        trueID = [trueID wordIdentity];
        trueClassCoding = zeros(length(settings.speechRecog.words), 1);
        trueClassCoding(wordIdentity) = 1;
        trueClass = [trueClass trueClassCoding];
        
        % classify word
        [word wordID onset duration confidence processingTime serverResponse] = recognizeWord(filepath);
        
        % store outcome values
        RTs = [RTs onset];
        classifiedID = [classifiedID wordID];
        if(wordID == wordIdentity)
            correct = [correct 1];
        else
            correct = [correct 0];
        end
        classifiedConfidence = [classifiedConfidence confidence];
        
        % confusion matrix: of none of the classes was detected, then guess
        % randomly
        if(isnan(wordID))
            guessedID = randsample(length(settings.speechRecog.words), 1);
        else
            guessedID = wordID;
        end
        guessedClassCoding = zeros(length(settings.speechRecog.words), 1);
        guessedClassCoding(guessedID) = 1;
        guessedClass = [guessedClass guessedClassCoding];

        % increment class counter
        counter = counter + 1;
        
    else
        continue
    end
    
end

% output results
accuracy = sum(correct)/length(correct);
disp(['Accuracy: ' num2str(accuracy*100) ' %']);

if(accuracy < 1)
    disp('----');
    disp('failed to correctly classify the following files: ');
    incorrectIdx = find(correct ==0);
    for i = 1:length(incorrectIdx);
        disp(filenames{incorrectIdx(i)});
    end
end

% summary plot

figure(1);
mat = [trueID' classifiedID' correct' classifiedConfidence'];
imagesc(mat); colorbar;
set(gca, 'XTick', 1:4);
set(gca, 'XTickLabels', {'True Word ID', 'Classified ID', 'Classification Accuracy', 'Confidence'});
title('Classificaiton Summary', 'FontSize', 14);

% confusion matrix

figure(2);
plotconfusion(trueClass, guessedClass);
set(gca, 'XTick', 1:length(settings.speechRecog.words), 'XTickLabel', settings.speechRecog.words);
set(gca, 'YTick', 1:length(settings.speechRecog.words), 'YTickLabel', settings.speechRecog.words);
xlabel('True Word', 'FontSize', 14);
ylabel('Recognized Word', 'FontSize', 14);
title('Confusion Matrix', 'FontSize', 14);
set(gcf, 'Color', 'w');

